@@ -20,17 +20,18 @@
 
 #include <QProcess>
 #include <QTimer>
-
+#include <KConfigGroup>
 #include <klineedit.h>
 #include <kiconloader.h>
-#include <kapplication.h>
-#include <kfiledialog.h>
-#include <kglobal.h>
 #include <ktoolinvocation.h>
 #include <kstandardguiitem.h>
-#include <kaction.h>
+#include <QAction>
 #include <kstandardaction.h>
 #include "kstatusnotifieritem.h"
+#include <KToolInvocation>
+#include <KHelpClient>
+#include <KGuiItem>
+#include <KSharedConfig>
 
 class KTimerJobItem : public QTreeWidgetItem {
 public:
@@ -66,16 +67,16 @@ public:
         setText( 0, m_job->formatTime(m_job->value()) );
 
         if( m_error )
-            setIcon( 0, KIcon( QLatin1String( "process-stop" )) );
+            setIcon( 0, QIcon::fromTheme( QLatin1String( "process-stop" )) );
         else
             setIcon( 0, QPixmap() );
 
         setText( 1, m_job->formatTime(m_job->delay()) );
 
         switch( m_job->state() ) {
-            case KTimerJob::Stopped: setIcon( 2, KIcon( QLatin1String( "media-playback-stop" )) ); break;
-            case KTimerJob::Paused: setIcon( 2, KIcon( QLatin1String( "media-playback-pause" )) ); break;
-            case KTimerJob::Started: setIcon( 2, KIcon( QLatin1String( "arrow-right" )) ); break;
+            case KTimerJob::Stopped: setIcon( 2, QIcon::fromTheme( QLatin1String( "media-playback-stop" )) ); break;
+            case KTimerJob::Paused: setIcon( 2, QIcon::fromTheme( QLatin1String( "media-playback-pause" )) ); break;
+            case KTimerJob::Started: setIcon( 2, QIcon::fromTheme( QLatin1String( "arrow-right" )) ); break;
         }
 
         setText( 3, m_job->command() );
@@ -103,9 +104,9 @@ KTimerPref::KTimerPref( QWidget *parent)
     setupUi(this);
 
     // set icons
-    m_stop->setIcon( KIcon( QLatin1String( "media-playback-stop" )) );
-    m_pause->setIcon( KIcon( QLatin1String( "media-playback-pause" )) );
-    m_start->setIcon( KIcon( QLatin1String( "arrow-right" )) );
+    m_stop->setIcon( QIcon::fromTheme( QLatin1String( "media-playback-stop" )) );
+    m_pause->setIcon( QIcon::fromTheme( QLatin1String( "media-playback-pause" )) );
+    m_start->setIcon( QIcon::fromTheme( QLatin1String( "arrow-right" )) );
 
     // create tray icon
     KStatusNotifierItem *tray = new KStatusNotifierItem(this);
@@ -113,19 +114,18 @@ KTimerPref::KTimerPref( QWidget *parent)
     tray->setCategory(KStatusNotifierItem::ApplicationStatus);
     tray->setStatus(KStatusNotifierItem::Active);
     // set help button gui item
-    m_help->setGuiItem(KStandardGuiItem::help());
+    KGuiItem::assign(m_help,KStandardGuiItem::help());
 
     // Exit
-    KAction *exit = KStandardAction::quit(this, SLOT(exit()), this);
+    QAction *exit = KStandardAction::quit(this, SLOT(exit()), this);
     addAction(exit);
 
     // connect
-    connect( m_add, SIGNAL(clicked()), SLOT(add()) );
-    connect( m_remove, SIGNAL(clicked()), SLOT(remove()) );
-    connect( m_help, SIGNAL(clicked()), SLOT(help()) );
-    connect( m_list, SIGNAL(currentItemChanged(QTreeWidgetItem*,QTreeWidgetItem*)),
-             SLOT(currentChanged(QTreeWidgetItem*,QTreeWidgetItem*)) );
-    loadJobs( KGlobal::config().data() );
+    connect(m_add, &QPushButton::clicked, this, &KTimerPref::add);
+    connect(m_remove, &QPushButton::clicked, this, &KTimerPref::remove);
+    connect(m_help, &QPushButton::clicked, this, &KTimerPref::help);
+    connect(m_list, &QTreeWidget::currentItemChanged, this, &KTimerPref::currentChanged);
+    loadJobs( KSharedConfig::openConfig().data() );
 
     show();
 }
@@ -137,7 +137,7 @@ KTimerPref::~KTimerPref()
 }
 
 void KTimerPref::saveAllJobs() {
-    saveJobs( KGlobal::config().data() );
+    saveJobs( KSharedConfig::openConfig().data() );
 }
 
 
@@ -146,16 +146,11 @@ void KTimerPref::add()
     KTimerJob *job = new KTimerJob;
     KTimerJobItem *item = new KTimerJobItem( job, m_list );
 
-    connect( job, SIGNAL(delayChanged(KTimerJob*,uint)),
-             SLOT(jobChanged(KTimerJob*)) );
-    connect( job, SIGNAL(valueChanged(KTimerJob*,uint)),
-             SLOT(jobChanged(KTimerJob*)) );
-    connect( job, SIGNAL(stateChanged(KTimerJob*,States)),
-             SLOT(jobChanged(KTimerJob*)) );
-    connect( job, SIGNAL(commandChanged(KTimerJob*,QString)),
-             SLOT(jobChanged(KTimerJob*)) );
-    connect( job, SIGNAL(finished(KTimerJob*,bool)),
-             SLOT(jobFinished(KTimerJob*,bool)) );
+    connect(job, &KTimerJob::delayChanged, this, &KTimerPref::jobChanged);
+    connect(job, &KTimerJob::valueChanged, this, &KTimerPref::jobChanged);
+    connect(job, &KTimerJob::stateChanged, this, &KTimerPref::jobChanged);
+    connect(job, &KTimerJob::commandChanged, this, &KTimerPref::jobChanged);
+    connect(job, &KTimerJob::finished, this, &KTimerPref::jobFinished);
 
     job->setUser( item );
 
@@ -176,7 +171,7 @@ void KTimerPref::remove()
 
 void KTimerPref::help()
 {
-    KToolInvocation::invokeHelp();
+    KHelpClient::invokeHelp();
 }
 
 // note, don't use old, but added it so we can connect to the new one
@@ -211,25 +206,18 @@ void KTimerPref::currentChanged( QTreeWidgetItem *i , QTreeWidgetItem * /* old *
 
         connect( m_commandLine->lineEdit(), SIGNAL(textChanged(QString)),
                  job, SLOT(setCommand(QString)) );
-        connect( m_delayH, SIGNAL(valueChanged(int)),
-                 SLOT(delayChanged()) );
-        connect( m_delayM, SIGNAL(valueChanged(int)),
-                 SLOT(delayChanged()) );
-        connect( m_delay, SIGNAL(valueChanged(int)),
-                 SLOT(delayChanged()) );
-        connect( m_loop, SIGNAL(toggled(bool)),
-                 job, SLOT(setLoop(bool)) );
-        connect( m_one, SIGNAL(toggled(bool)),
-                 job, SLOT(setOneInstance(bool)) );
-        connect( m_stop, SIGNAL(clicked()),
-                 job, SLOT(stop()) );
-        connect( m_pause, SIGNAL(clicked()),
-                 job, SLOT(pause()) );
-        connect( m_start, SIGNAL(clicked()),
-                 job, SLOT(start()) );
+        connect(m_delayH, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &KTimerPref::delayChanged);
+        connect(m_delayM, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &KTimerPref::delayChanged);
+        connect(m_delay, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &KTimerPref::delayChanged);
+        connect(m_loop, &QCheckBox::toggled, job, &KTimerJob::setLoop);
+        connect(m_one, &QCheckBox::toggled, job, &KTimerJob::setOneInstance);
+        connect(m_stop, &QToolButton::clicked, job, &KTimerJob::stop);
+        connect(m_pause, &QToolButton::clicked, job, &KTimerJob::pause);
+        connect(m_start, &QToolButton::clicked, job, &KTimerJob::start);
         connect( m_slider, SIGNAL(valueChanged(int)),
                  job, SLOT(setValue(int)) );
 
+
         m_commandLine->lineEdit()->setText( job->command() );
         m_loop->setChecked( job->loop() );
         m_one->setChecked( job->oneInstance() );
@@ -317,16 +305,11 @@ void KTimerPref::loadJobs( KConfig *cfg )
             KTimerJob *job = new KTimerJob;
             KTimerJobItem *item = new KTimerJobItem( job, m_list );
 
-            connect( job, SIGNAL(delayChanged(KTimerJob*,uint)),
-                     SLOT(jobChanged(KTimerJob*)) );
-            connect( job, SIGNAL(valueChanged(KTimerJob*,uint)),
-                     SLOT(jobChanged(KTimerJob*)) );
-            connect( job, SIGNAL(stateChanged(KTimerJob*,States)),
-                     SLOT(jobChanged(KTimerJob*)) );
-            connect( job, SIGNAL(commandChanged(KTimerJob*,QString)),
-                     SLOT(jobChanged(KTimerJob*)) );
-            connect( job, SIGNAL(finished(KTimerJob*,bool)),
-                     SLOT(jobFinished(KTimerJob*,bool)) );
+            connect(job, &KTimerJob::delayChanged, this, &KTimerPref::jobChanged);
+            connect(job, &KTimerJob::valueChanged, this, &KTimerPref::jobChanged);
+            connect(job, &KTimerJob::stateChanged, this, &KTimerPref::jobChanged);
+            connect(job, &KTimerJob::commandChanged, this, &KTimerPref::jobChanged);
+            connect(job, &KTimerJob::finished, this, &KTimerPref::jobFinished);
 
             job->load( cfg, QString( QLatin1String( "Job%1" ) ).arg(n) );
 
@@ -368,7 +351,7 @@ KTimerJob::KTimerJob( QObject *parent)
     d->user = 0;
 
     d->timer = new QTimer( this );
-    connect( d->timer, SIGNAL(timeout()), SLOT(timeout()) );
+    connect(d->timer, &QTimer::timeout, this, &KTimerJob::timeout);
 }
 
 
@@ -606,8 +589,7 @@ void KTimerJob::fire()
     if( !d->oneInstance || d->processes.isEmpty() ) {
         QProcess *proc = new QProcess;
         d->processes.append( proc );
-        connect( proc, SIGNAL(finished(int,QProcess::ExitStatus)),
-                 SLOT(processExited(int,QProcess::ExitStatus)) );
+        connect(proc, static_cast<void (QProcess::*)(int, QProcess::ExitStatus)>(&QProcess::finished), this, &KTimerJob::processExited);
         if (!d->command.simplified ().isEmpty()) {
 	        proc->start(d->command);
 	        emit fired( this );
@@ -621,4 +603,4 @@ void KTimerJob::fire()
         }
     }
 }
-#include "ktimer.moc"
+
